projectal.entities.tag API documentation

# projectal.entities.tag

View Source

     1from projectal.entity import Entity
     2
     3
     4class Tag(Entity):
     5    """
     6    Implementation of the [Tag](https://projectal.com/docs/latest/#tag/Tag) API.
     7    """
     8
     9    _path = "tag"
    10    _name = "tag"
    11    _links = []
    12    _links_reverse = []

class Tag(projectal.entity.Entity): View Source

     5class Tag(Entity):
     6    """
     7    Implementation of the [Tag](https://projectal.com/docs/latest/#tag/Tag) API.
     8    """
     9
    10    _path = "tag"
    11    _name = "tag"
    12    _links = []
    13    _links_reverse = []

Implementation of the Tag API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy